@@ -7,7 +7,9 @@ Python ``@deprecated`` decorator to deprecate old python classes, functions or m
 
 """
 
-#: Module Version Number, see `PEP 396 <https://www.python.org/dev/peps/pep-0396/>`_.
-__version__ = "1.2.10"
+__version__ = "1.2.12"
+__author__ = u"Laurent LAPORTE <tantale.solutions@gmail.com>"
+__date__ = "2020-03-13"
+__credits__ = "(c) Laurent LAPORTE"
 
 from deprecated.classic import deprecated
